@@ -296,7 +296,9 @@ class GsDataApi(DataApi):
             # We require the Dataframe to return a list in the 'records' format:
             #  https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.to_json.html
             data = data.to_json(orient='records')
-        result = GsSession.current._post('/data/{}'.format(dataset_id), payload=data)
+        # Don't use msgpack for MDS
+        headers = None if 'us-east' in GsSession.current.domain else {'Content-Type': 'application/x-msgpack'}
+        result = GsSession.current._post('/data/{}'.format(dataset_id), payload=data, request_headers=headers)
         return result
 
     @classmethod
