@@ -17,7 +17,6 @@ under the License.
 import logging
 from copy import copy
 from datetime import date, datetime
-from re import search
 from typing import Union, Optional, List
 
 import gs_quant.datetime.rules as rules
@@ -51,7 +50,7 @@ class RelativeDate:
     **Documentation**
 
     Full Documentation and examples can be found here:
-    https://developer.gs.com/docs/gsquant/tutorials/Markets/dates/
+    https://developer.gs.com/docs/gsquant/api/datetime.html
 
     """
 
@@ -130,17 +129,25 @@ class RelativeDate:
                       holiday_calendar: List[date] = None,
                       **kwargs) -> date:
         if rule.startswith('-'):
-            number_match = search('\d+', rule[1:])
-            number = int(number_match.group(0)) * -1 if number_match else 0
-            rule_str = rule[number_match.endpos:]
+            index = 1
+            while index != len(rule) and rule[index].isdigit():
+                index += 1
+            number = int(rule[1:index]) * -1 if index < len(rule) else 0
+            rule_str = rule[index]
         else:
-            number_match = search('\d+', rule)
-            if number_match:
-                rule_str = rule[number_match.endpos - 1:]
-                number = int(number_match.group(0))
-            else:
+            index = 0
+            if not rule[0].isdigit():
                 rule_str = rule
                 number = 0
+            else:
+                while index != len(rule) and rule[index].isdigit():
+                    index += 1
+                if index < len(rule):
+                    number = int(rule[0:index])
+                    rule_str = rule[index]
+                else:
+                    rule_str = rule
+                    number = 0
 
         if not rule_str:
             raise MqValueError(f'Invalid rule "{rule}"')
@@ -163,3 +170,81 @@ class RelativeDate:
         if self.base_date_passed_in:
             rdate_dict['baseDate'] = str(self.base_date)
         return rdate_dict
+
+
+class RelativeDateSchedule:
+    """
+        RelativeDatesSchedules are objects which wrap a RelativeDate to provide a schedule between two dates
+        Some rules require a business day calendar.
+
+        :param rule: Rule to use
+        :param base_date: Base date to use (Optional).
+        :param end_date: No dates past this date will be returned (Optional).
+        :return: new RelativeDateSchedule object
+
+        **Usage**
+
+        Create a RelativeDateSchedule object and then call `apply_rule` to get a date schedule back.
+
+        **Examples**
+
+        RelativeDateSchedule to return a schedule from today to 1w in the future
+
+        >>> my_date: date = RelativeDateSchedule('1w', datetime.date.today(), ).apply_rule()
+
+        """
+
+    def __init__(self,
+                 rule: str,
+                 base_date: Optional[date] = None,
+                 end_date: Optional[date] = None):
+        self.rule = rule
+        self.base_date_passed_in = False
+        if base_date:
+            self.base_date = base_date
+            self.base_date_passed_in = True
+        elif PricingContext.current.is_entered:
+            pricing_date = PricingContext.current.pricing_date
+            self.base_date = pricing_date.date() if isinstance(pricing_date, datetime) else pricing_date
+        else:
+            self.base_date = date.today()
+        self.end_date = end_date
+
+    def apply_rule(self,
+                   currencies: List[Union[Currency, str]] = None,
+                   exchanges: List[Union[ExchangeCode, str]] = None,
+                   holiday_calendar: List[date] = None,
+                   week_mask: str = '1111100',
+                   **kwargs) -> List[date]:
+        """
+        Applies business date logic on the rule using the given holiday calendars for rules that use business
+        day logic. week_mask is based off
+        https://numpy.org/doc/stable/reference/generated/numpy.busdaycalendar.weekmask.html.
+
+        :param holiday_calendar: Optional list of date to use for holiday calendar. This parameter takes precedence over
+        currencies/exchanges.
+        :param currencies: List of currency holiday calendars to use. (GS Internal only)
+        :param exchanges: List of exchange holiday calendars to use.
+        :param week_mask: String of seven-element boolean mask indicating valid days. Default weekend is Sat and Sun.
+        :return: dt.date
+        """
+
+        i = 1
+        schedule = [self.base_date]
+        while True:
+            rule = f'{int(self.rule[:-1]) * i}{self.rule[-1]}'
+            result = RelativeDate(rule, self.base_date).apply_rule(currencies, exchanges, holiday_calendar, week_mask,
+                                                                   **kwargs)
+            if self.end_date is None or result > self.end_date:
+                break
+            i += 1
+            schedule.append(result)
+
+        return schedule
+
+    def as_dict(self):
+        rdate_dict = {'rule': self.rule}
+        if self.base_date_passed_in:
+            rdate_dict['baseDate'] = str(self.base_date)
+        rdate_dict['endDate'] = str(self.end_date)
+        return rdate_dict
