@@ -23,9 +23,11 @@ from typing import Any, Iterable, Mapping, Optional, Tuple, Union
 
 import pandas as pd
 from gs_quant.base import Priceable, RiskKey, Sentinel, InstrumentBase, is_instance_or_iterable, is_iterable
+from gs_quant.common import RiskMeasure
 from gs_quant.config import DisplayOptions
-from gs_quant.risk import DataFrameWithInfo, ErrorValue, FloatWithInfo, RiskMeasure, SeriesWithInfo, ResultInfo, \
+from gs_quant.risk import DataFrameWithInfo, ErrorValue, FloatWithInfo, SeriesWithInfo, ResultInfo, \
     ScalarWithInfo, aggregate_results
+from gs_quant.target.common import AssetType
 from more_itertools import unique_everseen
 
 _logger = logging.getLogger(__name__)
@@ -92,7 +94,7 @@ def _value_for_date(result: Union[DataFrameWithInfo, SeriesWithInfo], date: Unio
         return FloatWithInfo(
             risk_key,
             raw_value,
-            unit=result.unit.get(date, '') if result.unit else None,
+            unit=result.unit.get(date, result.unit) if result.unit else None,
             error=result.error)
 
 
@@ -599,8 +601,11 @@ class PortfolioRiskResult(CompositeResultFuture):
     def to_frame(self, values='default', index='default', columns='default', aggfunc=sum,
                  display_options: DisplayOptions = None):
         def get_name(obj, idx):
-            new_name = f'{obj.type.name}_{idx}' if isinstance(obj, InstrumentBase) else f'Portfolio_{idx}'
-            return new_name if obj.name is None else obj.name
+            if isinstance(obj, InstrumentBase) and hasattr(obj, 'type'):
+                type_name = obj.type.name if isinstance(obj.type, AssetType) else obj._type
+            else:
+                type_name = 'Portfolio'
+            return f'{type_name}_{idx}' if obj.name is None else obj.name
 
         def get_df(priceable):
             portfolio_paths = list(unique_everseen(p.path[:-1] for p in priceable.all_paths if len(p.path) > 1))
